@@ -3,10 +3,14 @@ import random
 import string
 
 from django.db import models
-from django.utils.translation import gettext as _
+from django.utils.translation import gettext_lazy as _
 
 from ..get_settings import extract_model_kwargs as ek
 
+__all__ = [
+    "RandomIDMixin"
+]
+
 
 class RandomIDMixin(models.Model):
     """
